package # Hide from CPAN
    LM::Test::Component;
use Moose;

extends 'Graphics::Primitive::Component';

sub prepare { }

1;